@@ -1,15 +1,7 @@
 use structopt::StructOpt;
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, StructOpt, Default)]
 pub struct Opt {
-    /// Sets the timeout for all the notifiers.
-    #[structopt(
-        long = "timeout",
-        short = "t",
-        help = "Specify how long (in seconds) notifications appear for"
-    )]
-    timeout: u32,
-
     /// Notifies you about your system's uptime.
     #[structopt(
         long = "uptime",
@@ -18,13 +10,21 @@ pub struct Opt {
     )]
     pub uptime: bool,
 
+    /// Sets the timeout for all the notifiers, `get_timeout()` converts this to seconds.
+    #[structopt(
+        long = "timeout",
+        short = "t",
+        help = "Specify how long (in seconds) notifications appear for"
+    )]
+    pub timeout: Option<u32>,
+
     /// Notifies you about your system's date and time.
     #[structopt(
         long = "date",
         short = "d",
         help = "Send a notification with date information"
     )]
-    pub date_time: bool,
+    pub date: bool,
 
     /// Notifies you about your system's battery percentage and status.
     #[structopt(
@@ -50,6 +50,14 @@ pub struct Opt {
     )]
     pub memory: bool,
 
+    /// Notifies you about your system's backlight.
+    #[structopt(
+        long = "backlight",
+        short = "l",
+        help = "Send a notification with backlight information"
+    )]
+    pub backlight: bool,
+
     /// Specify an interface for the network notifier.
     #[structopt(
         long = "interface",
@@ -57,24 +65,12 @@ pub struct Opt {
         help = "Specify the interface for the network notification"
     )]
     pub interface: Option<String>,
-}
 
-impl Default for Opt {
-    fn default() -> Self {
-        Opt {
-            timeout: 5,
-            uptime: false,
-            date_time: false,
-            battery: false,
-            network: false,
-            memory: false,
-            interface: None,
-        }
-    }
-}
+    /// Provides debug information.
+    #[structopt(long = "debug", short = "D", help = "Provides debug information")]
+    pub debug: bool,
 
-impl Opt {
-    pub fn get_timeout(&self) -> u32 {
-        self.timeout * 1000
-    }
+    /// Prints version information.
+    #[structopt(long = "version", short = "V", help = "Prints version information")]
+    pub version: bool,
 }
